@@ -1,6 +1,8 @@
 #import chardet
 import pkgutil
 import yaml
+import re
+
 from chardet.universaldetector import UniversalDetector
 from io import BytesIO
 
@@ -16,11 +18,15 @@ from pywb.utils.bufferedreaders import ChunkedDataReader
 
 #=================================================================
 class RewriteContent:
-    def __init__(self, ds_rules_file=None, defmod=''):
+    def __init__(self, ds_rules_file=None, is_framed_replay=False):
         self.ruleset = RuleSet(RewriteRules, 'rewrite',
                                default_rule_config={},
                                ds_rules_file=ds_rules_file)
-        self.defmod = defmod
+
+        if is_framed_replay:
+            self.defmod = 'mp_'
+        else:
+            self.defmod = ''
 
     def sanitize_content(self, status_headers, stream):
         # remove transfer encoding chunked and wrap in a dechunking stream
@@ -54,9 +60,12 @@ class RewriteContent:
 
     def rewrite_content(self, urlrewriter, headers, stream,
                         head_insert_func=None, urlkey='',
-                        sanitize_only=False, cdx=None, mod=None):
+                        cdx=None):
 
-        if sanitize_only:
+        wb_url = urlrewriter.wburl
+
+        if (wb_url.is_identity or
+            (not head_insert_func and wb_url.is_banner_only)):
             status_headers, stream = self.sanitize_content(headers, stream)
             return (status_headers, self.stream_to_gen(stream), False)
 
@@ -78,6 +87,8 @@ class RewriteContent:
 
         # see known js/css modifier specified, the context should run
         # default text_type
+        mod = wb_url.mod
+
         if mod == 'js_':
             text_type = 'js'
         elif mod == 'cs_':
@@ -96,16 +107,6 @@ class RewriteContent:
             else:
                 stream = DecompressingBufferedReader(stream)
 
-        #if self.decode_stream:
-        #    if rewritten_headers.charset:
-        #        encoding = rewritten_headers.charset
-        #    else:
-        #        (encoding, first_buff) = self._detect_charset(stream)
-
-            # if encoding not set or chardet thinks its ascii, use utf-8
-        #    if not encoding or encoding == 'ascii':
-        #        encoding = 'utf-8'
-
         rule = self.ruleset.get_first_match(urlkey)
 
         rewriter_class = rule.rewriters[text_type]
@@ -118,6 +119,10 @@ class RewriteContent:
             if head_insert_func:
                 head_insert_str = head_insert_func(rule, cdx)
 
+            if wb_url.is_banner_only:
+                gen = self._head_insert_only_gen(head_insert_str, stream)
+                return (status_headers, gen, False)
+
             rewriter = rewriter_class(urlrewriter,
                                       js_rewriter_class=rule.rewriters['js'],
                                       css_rewriter_class=rule.rewriters['css'],
@@ -125,39 +130,45 @@ class RewriteContent:
                                       defmod=self.defmod)
 
         else:
-        # apply one of (js, css, xml) rewriters
+            if wb_url.is_banner_only:
+                return (status_headers, self.stream_to_gen(stream), False)
+
+            # apply one of (js, css, xml) rewriters
             rewriter = rewriter_class(urlrewriter)
 
         # Create rewriting generator
-        gen = self._rewriting_stream_gen(rewriter, encoding,
-                                         stream, first_buff)
+        gen =  self.stream_to_gen(stream,
+                                  rewrite_func=rewriter.rewrite,
+                                  final_read_func=rewriter.close,
+                                  first_buff=first_buff)
+
 
         return (status_headers, gen, True)
 
-    # Create rewrite stream,  may even be chunked by front-end
-    def _rewriting_stream_gen(self, rewriter, encoding,
-                              stream, first_buff=None):
+    HEAD_REGEX = re.compile(r'<\s*head\b[^>]*[>]+', re.I)
 
-        def do_rewrite(buff):
-            if encoding:
-                buff = self._decode_buff(buff, stream, encoding)
-            buff = rewriter.rewrite(buff)
-            if encoding:
-                buff = buff.encode(encoding)
+    def _head_insert_only_gen(self, insert_str, stream):
+        max_len = 1024
+        buff = ''
+        while max_len > 0:
+            curr = stream.read(max_len)
+            if not curr:
+                break
 
-            return buff
+            max_len -= len(buff)
+            buff += curr
 
-        def do_finish():
-            result = rewriter.close()
-            if encoding:
-                result = result.encode(encoding)
+        matcher = self.HEAD_REGEX.search(buff)
 
-            return result
+        if matcher:
+            yield buff[:matcher.end()] + insert_str
+            yield buff[matcher.end():]
+        else:
+            yield insert_str
+            yield buff
 
-        return self.stream_to_gen(stream,
-                                  rewrite_func=do_rewrite,
-                                  final_read_func=do_finish,
-                                  first_buff=first_buff)
+        for buff in self.stream_to_gen(stream):
+            yield buff
 
     @staticmethod
     def _decode_buff(buff, stream, encoding):  # pragma: no coverage
@@ -177,26 +188,6 @@ class RewriteContent:
 
         return buff
 
-    def _detect_charset(self, stream):  # pragma: no coverage
-        full_buff = stream.read(8192)
-        io_buff = BytesIO(full_buff)
-
-        detector = UniversalDetector()
-
-        try:
-            buff = io_buff.read(256)
-            while buff:
-                detector.feed(buff)
-                if detector.done:
-                    break
-
-                buff = io_buff.read(256)
-        finally:
-            detector.close()
-
-        print "chardet result: ", str(detector.result)
-        return (detector.result['encoding'], full_buff)
-
     # Create a generator reading from a stream,
     # with optional rewriting and final read call
     @staticmethod
