@@ -121,16 +121,18 @@ def add_env_globals(glb):
 
 #=================================================================
 class HeadInsertView(J2TemplateView):
-    def create_insert_func(self, wbrequest, include_ts=True):
+    def create_insert_func(self, wbrequest,
+                           include_ts=True):
 
         canon_url = wbrequest.wb_prefix + wbrequest.wb_url.to_str(mod='')
-        include_ts = include_ts
+        include_wombat = not wbrequest.wb_url.is_banner_only
 
         def make_head_insert(rule, cdx):
             return (self.render_to_string(wbrequest=wbrequest,
                                           cdx=cdx,
                                           canon_url=canon_url,
                                           include_ts=include_ts,
+                                          include_wombat=include_wombat,
                                           rule=rule))
         return make_head_insert
 
@@ -139,6 +141,14 @@ class HeadInsertView(J2TemplateView):
         return J2TemplateView.create_template(filename, desc,
                                               HeadInsertView)
 
+    @staticmethod
+    def init_from_config(config):
+        view = config.get('head_insert_view')
+        if not view:
+            html = config.get('head_insert_html', 'ui/head_insert.html')
+            view = HeadInsertView.create_template(html, 'Head Insert')
+        return view
+
 
 #=================================================================
 # query views
