@@ -96,15 +96,16 @@ class TestWb:
         resp = self.testapp.get('/pywb/20140127171238mp_/http://www.iana.org/')
         self._assert_basic_html(resp)
 
-        assert 'Mon, Jan 27 2014 17:12:38' in resp.body
+        assert '"20140127171238"' in resp.body
         assert 'wb.js' in resp.body
+        assert 'WB_wombat_init' in resp.body
         assert '/pywb/20140127171238mp_/http://www.iana.org/time-zones"' in resp.body
 
     def test_replay_non_frame_content(self):
         resp = self.testapp.get('/pywb-nonframe/20140127171238/http://www.iana.org/')
         self._assert_basic_html(resp)
 
-        assert 'Mon, Jan 27 2014 17:12:38' in resp.body
+        assert '"20140127171238"' in resp.body
         assert 'wb.js' in resp.body
         assert '/pywb-nonframe/20140127171238/http://www.iana.org/time-zones"' in resp.body
 
@@ -112,7 +113,7 @@ class TestWb:
         resp = self.testapp.get('/pywb-nosurt/20140103030321mp_/http://example.com?example=1')
         self._assert_basic_html(resp)
 
-        assert 'Fri, Jan 03 2014 03:03:21' in resp.body
+        assert '"20140103030321"' in resp.body
         assert 'wb.js' in resp.body
         assert '/pywb-nosurt/20140103030321mp_/http://www.iana.org/domains/example' in resp.body
 
@@ -120,7 +121,7 @@ class TestWb:
         resp = self.testapp.get('/pywb/20140603030341mp_/http://example.com?example=2')
         self._assert_basic_html(resp)
 
-        assert 'Tue, Jun 03 2014 03:03:41' in resp.body
+        assert '"20140603030341"' in resp.body
         assert 'wb.js' in resp.body
         assert '/pywb/20140603030341mp_/http://www.iana.org/domains/example' in resp.body
 
@@ -128,7 +129,7 @@ class TestWb:
         resp = self.testapp.get('/pywb/20130729195151mp_/http://www.example.com/')
         self._assert_basic_html(resp)
 
-        assert 'Mon, Jul 29 2013 19:51:51' in resp.body
+        assert '"20130729195151"' in resp.body
         assert 'wb.js' in resp.body
         assert '/pywb/20130729195151mp_/http://www.iana.org/domains/example"' in resp.body
 
@@ -141,6 +142,19 @@ class TestWb:
         assert lines[0].startswith('org,iana)/_css/2013.1/print.css 20140127171239')
 
 
+    def test_replay_banner_only(self):
+        resp = self.testapp.get('/pywb/20140126201054bn_/http://www.iana.org/domains/reserved')
+
+        # wb.js header insertion
+        assert 'wb.js' in resp.body
+
+        # no wombat present
+        assert 'WB_wombat_init' not in resp.body
+
+        # url not rewritten
+        #assert '"http://www.iana.org/domains/example"' in resp.body
+        assert '"/_css/2013.1/screen.css"' in resp.body
+
     def test_replay_identity_1(self):
         resp = self.testapp.get('/pywb/20140127171251id_/http://example.com')
 
@@ -201,7 +215,7 @@ class TestWb:
 
         #check resp
         self._assert_basic_html(resp)
-        assert 'Mon, Jan 27 2014 17:12:51' in resp.body
+        assert '"20140127171251"' in resp.body
         assert '/pywb/20140127171251mp_/http://www.iana.org/domains/example' in resp.body
 
     def test_redirect_relative_3(self):
@@ -287,6 +301,11 @@ class TestWb:
         assert resp.status_int == 200
         assert '"data": "^"' in resp.body
 
+    def test_post_invalid(self):
+        # not json
+        resp = self.testapp.post_json('/pywb/20140610001255mp_/http://httpbin.org/post?foo=bar', {'data': '^'}, status=404)
+        assert resp.status_int == 404
+
     def test_post_redirect(self):
         # post handled without redirect (since 307 not allowed)
         resp = self.testapp.post('/post', {'foo': 'bar', 'test': 'abc'}, headers=[('Referer', 'http://localhost:8080/pywb/2014mp_/http://httpbin.org/post')])
@@ -294,9 +313,8 @@ class TestWb:
         assert '"foo": "bar"' in resp.body
         assert '"test": "abc"' in resp.body
 
-
     def test_excluded_content(self):
-        resp = self.testapp.get('/pywb/http://www.iana.org/_img/bookmark_icon.ico', status = 403)
+        resp = self.testapp.get('/pywb/mp_/http://www.iana.org/_img/bookmark_icon.ico', status = 403)
         assert resp.status_int == 403
         assert 'Excluded' in resp.body
 
@@ -323,7 +341,7 @@ class TestWb:
         resp = self.testapp.get('/x-ignore-this-x', extra_environ = dict(REQUEST_URI = 'http://www.iana.org/domains/idn-tables', SCRIPT_NAME = ''))
         self._assert_basic_html(resp)
 
-        assert 'Sun, Jan 26 2014 20:11:27' in resp.body
+        assert '"20140126201127"' in resp.body
         assert 'wb.js' in resp.body
 
     def test_proxy_replay_auth_filtered(self):
@@ -333,7 +351,7 @@ class TestWb:
 
         self._assert_basic_html(resp)
 
-        assert 'Sun, Jan 26 2014 20:06:24' in resp.body
+        assert '"20140126200624"' in resp.body
         assert 'wb.js' in resp.body
 
     def test_proxy_replay_auth(self):
@@ -343,7 +361,7 @@ class TestWb:
 
         self._assert_basic_html(resp)
 
-        assert 'Mon, Jan 27 2014 17:12:38' in resp.body
+        assert '"20140127171238"' in resp.body
         assert 'wb.js' in resp.body
 
     def test_proxy_replay_auth_no_coll(self):
@@ -400,7 +418,7 @@ class TestWb:
 
 
     def test_error(self):
-        resp = self.testapp.get('/pywb/?abc', status = 400)
+        resp = self.testapp.get('/pywb/mp_/?abc', status = 400)
         assert resp.status_int == 400
         assert 'Invalid Url: http://?abc' in resp.body
 
